@@ -1,13 +1,14 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-01-20'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use Moose;
 with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 
+has bench => (is=>'rw', default=>sub{1});
 has sample_bench => (is=>'rw');
 
 sub mvp_multivalue_args { qw(sample_bench) }
@@ -113,7 +114,9 @@ sub _process_module {
         my @pod;
 
         my $sample_benches;
-        if ($self->sample_bench && @{ $self->sample_bench }) {
+        if (!$self->bench) {
+            $sample_benches = [];
+        } elsif ($self->sample_bench && @{ $self->sample_bench }) {
             $sample_benches = [];
             my $i = -1;
             for (@{ $self->sample_bench }) {
@@ -138,6 +141,8 @@ sub _process_module {
             ];
         }
 
+        last unless @$sample_benches;
+
         my $i = -1;
         for my $bench (@$sample_benches) {
             $i++;
@@ -198,6 +203,8 @@ sub _process_module {
         last unless @modules;
         my @pod;
 
+        push @pod, qq(Version numbers shown below are the versions used when running the sample benchmark.\n\n);
+
         for my $mod (@modules) {
             push @pod, "L<$mod>";
             my $v;
@@ -320,7 +327,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.10 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-20.
+This document describes version 0.11 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
@@ -352,6 +359,14 @@ run and shown.
 
 =for Pod::Coverage .*
 
+=head1 OPTIONS
+
+=head2 sample_bench => hash
+
+=head2 bench => bool (default: 1)
+
+Set to 0 if you do not want to produce sample results
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-Bencher-Scenario>.
